"""
MVP Notes
  User Flow
    Sign into site, get project ID/secret
    Install middleware, add config (i.e. project id/secret, service name, environment)
    Run locally and/or deploy
    See dashboards and alerts
  Flask middleware
    Send metrics for latency, success, errors
  Command Center
    Config
    Dashboards per service
    Alerts per service
"""
